@@ -22,7 +22,7 @@ public:
   /** Create a parser with an empty document.
    * @throws xmlpp::internal_error If an empty document can't be created.
    */
-  DomParser();
+  LIBXMLPP_API DomParser();
 
   /** Instantiate the parser and parse a document immediately.
    * @param filename The path to the file.
@@ -31,8 +31,36 @@ public:
    * @throws xmlpp::parse_error
    * @throws xmlpp::validity_error
    */
+  LIBXMLPP_API
   explicit DomParser(const Glib::ustring& filename, bool validate = false);
-  virtual ~DomParser();
+  LIBXMLPP_API ~DomParser() override;
+
+  /** Set whether and how the parser will perform XInclude substitution.
+   *
+   * @newin{2,42}
+   *
+   * @param process_xinclude Do XInclude substitution on the XML document.
+   *        If <tt>false</tt>, the other parameters have no effect.
+   * @param generate_xinclude_nodes Generate XIncludeStart and XIncludeEnd nodes.
+   * @param fixup_base_uris Add or replace xml:base attributes in included element
+   *        nodes, if necessary to preserve the target of relative URIs.
+   */
+  LIBXMLPP_API
+  void set_xinclude_options(bool process_xinclude = true,
+    bool generate_xinclude_nodes = true, bool fixup_base_uris = true) noexcept;
+
+  /** Get whether and how the parser will perform XInclude substitution.
+   *
+   * @newin{2,42}
+   *
+   * @param[out] process_xinclude Do XInclude substitution on the XML document.
+   * @param[out] generate_xinclude_nodes Generate XIncludeStart and XIncludeEnd nodes.
+   * @param[out] fixup_base_uris Add or replace xml:base attributes in included element
+   *        nodes, if necessary to preserve the target of relative URIs.
+   */
+  LIBXMLPP_API
+  void get_xinclude_options(bool& process_xinclude,
+    bool& generate_xinclude_nodes, bool& fixup_base_uris) const noexcept;
 
   /** Parse an XML document from a file.
    * If the parser already contains a document, that document and all its nodes
@@ -42,7 +70,8 @@ public:
    * @throws xmlpp::parse_error
    * @throws xmlpp::validity_error
    */
-  virtual void parse_file(const Glib::ustring& filename);
+  LIBXMLPP_API
+  void parse_file(const Glib::ustring& filename) override;
 
   /** Parse an XML document from a string.
    * If the parser already contains a document, that document and all its nodes
@@ -52,7 +81,8 @@ public:
    * @throws xmlpp::parse_error
    * @throws xmlpp::validity_error
    */
-  virtual void parse_memory(const Glib::ustring& contents);
+  LIBXMLPP_API
+  void parse_memory(const Glib::ustring& contents) override;
   
   /** Parse an XML document from raw memory.
    * If the parser already contains a document, that document and all its nodes
@@ -63,6 +93,7 @@ public:
    * @throws xmlpp::parse_error
    * @throws xmlpp::validity_error
    */
+  LIBXMLPP_API
   void parse_memory_raw(const unsigned char* contents, size_type bytes_count);
 
   /** Parse an XML document from a stream.
@@ -73,26 +104,31 @@ public:
    * @throws xmlpp::parse_error
    * @throws xmlpp::validity_error
    */
-  virtual void parse_stream(std::istream& in);
+  LIBXMLPP_API
+  void parse_stream(std::istream& in) override;
 
   /** Test whether a document has been parsed.
    */
-  operator bool() const;
+  LIBXMLPP_API operator bool() const;
   
   /** Get the parsed document.
-   * @returns A pointer to the parsed document, or <tt>0</tt>.
+   * @returns A pointer to the parsed document, or <tt>nullptr</tt>.
    */
-  Document* get_document();
+  LIBXMLPP_API Document* get_document();
 
   /** Get the parsed document.
-   * @returns A pointer to the parsed document, or <tt>0</tt>.
+   * @returns A pointer to the parsed document, or <tt>nullptr</tt>.
    */
-  const Document* get_document() const;
+  LIBXMLPP_API const Document* get_document() const;
   
 protected:
-  virtual void parse_context();
+  //TODO: Remove the virtual when we can break ABI?
+  LIBXMLPP_API virtual void parse_context();
+  LIBXMLPP_API
+  void check_xinclude_and_finish_parsing();
 
-  virtual void release_underlying();
+  LIBXMLPP_API
+  void release_underlying() override;
   
   Document* doc_;
 };
